@@ -435,17 +435,19 @@ extract_hof <- function(x, xml_str) {
 }
 
 
-
 copy_header_references_everywhere <- function(x, xml_str) {
   xml_body <- docx_body_xml(x)
 
-  all_ref <- xml_find_all(xml_body, "/w:document/w:body/w:sectPr/w:headerReference")
+  all_ref <- xml_find_all(
+    xml_body,
+    "/w:document/w:body/w:sectPr/w:headerReference"
+  )
   all_ref <- as.character(all_ref)
   all_ref <- paste0(all_ref, collapse = "")
   m <- regexpr("(?=</w:sectPr)", xml_str, perl = TRUE)
 
-  default_sect_pos <- tail(which(m>-1), n = 1)
-  attr(m,"match.length")[default_sect_pos] <- -1
+  default_sect_pos <- tail(which(m > -1), n = 1)
+  attr(m, "match.length")[default_sect_pos] <- -1
   m[default_sect_pos] <- -1
 
   regmatches(xml_str, m) <- all_ref
@@ -456,13 +458,16 @@ copy_header_references_everywhere <- function(x, xml_str) {
 copy_footer_references_everywhere <- function(x, xml_str) {
   xml_body <- docx_body_xml(x)
 
-  all_ref <- xml_find_all(xml_body, "/w:document/w:body/w:sectPr/w:footerReference")
+  all_ref <- xml_find_all(
+    xml_body,
+    "/w:document/w:body/w:sectPr/w:footerReference"
+  )
   all_ref <- as.character(all_ref)
   all_ref <- paste0(all_ref, collapse = "")
   m <- regexpr("(?=</w:sectPr)", xml_str, perl = TRUE)
 
-  default_sect_pos <- tail(which(m>-1), n = 1)
-  attr(m,"match.length")[default_sect_pos] <- -1
+  default_sect_pos <- tail(which(m > -1), n = 1)
+  attr(m, "match.length")[default_sect_pos] <- -1
   m[default_sect_pos] <- -1
 
   regmatches(xml_str, m) <- all_ref
